==> haskell-time-locale-compat-0.1.1.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-locale-compat
version: 0.1.1.5
id: time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
key: time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
license: BSD-3-Clause
copyright: Copyright (c) 2014-2018 Kei Hibino
maintainer: ex8k.hibino@gmail.com
author: Kei Hibino
homepage: https://github.com/khibino/haskell-time-locale-compat
synopsis: Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.
category: System
abi: 8e7cbe9859e6b2fba2bf52bd3dee4d4a
exposed: True
exposed-modules:
    Data.Time.Locale.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/time-locale-compat-0.1.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/time-locale-compat-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/time-locale-compat-0.1.1.5
hs-libraries: HStime-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
depends:
    base-4.11.1.0 time-1.8.0.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
haddock-interfaces: /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock
haddock-html: /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-locale-compat-0.1.1.5-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-locale-compat
version: 0.1.1.5
id: time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
key: time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
license: BSD-3-Clause
copyright: Copyright (c) 2014-2018 Kei Hibino
maintainer: ex8k.hibino@gmail.com
author: Kei Hibino
homepage: https://github.com/khibino/haskell-time-locale-compat
synopsis: Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.
category: System
abi: d674ae9c874ee8d58b93740c0487f782
exposed: True
exposed-modules:
    Data.Time.Locale.Compat
import-dirs: /usr/lib/ghc-8.6.1/site-local/time-locale-compat-0.1.1.5
library-dirs: /usr/lib/ghc-8.6.1/site-local/time-locale-compat-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/time-locale-compat-0.1.1.5
hs-libraries: HStime-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
depends:
    base-4.12.0.0 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock
haddock-html: /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
